# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class News(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'category': 'str',
        'datetime': 'int',
        'headline': 'str',
        'id': 'int',
        'image': 'str',
        'related': 'str',
        'source': 'str',
        'summary': 'str',
        'url': 'str'
    }

    attribute_map = {
        'category': 'category',
        'datetime': 'datetime',
        'headline': 'headline',
        'id': 'id',
        'image': 'image',
        'related': 'related',
        'source': 'source',
        'summary': 'summary',
        'url': 'url'
    }

    def __init__(self, category=None, datetime=None, headline=None, id=None, image=None, related=None, source=None, summary=None, url=None, local_vars_configuration=None):  # noqa: E501
        """News - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._category = None
        self._datetime = None
        self._headline = None
        self._id = None
        self._image = None
        self._related = None
        self._source = None
        self._summary = None
        self._url = None
        self.discriminator = None

        if category is not None:
            self.category = category
        if datetime is not None:
            self.datetime = datetime
        if headline is not None:
            self.headline = headline
        if id is not None:
            self.id = id
        if image is not None:
            self.image = image
        if related is not None:
            self.related = related
        if source is not None:
            self.source = source
        if summary is not None:
            self.summary = summary
        if url is not None:
            self.url = url

    @property
    def category(self):
        """Gets the category of this News.  # noqa: E501

        News category.  # noqa: E501

        :return: The category of this News.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this News.

        News category.  # noqa: E501

        :param category: The category of this News.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def datetime(self):
        """Gets the datetime of this News.  # noqa: E501

        Published time in UNIX timestamp.  # noqa: E501

        :return: The datetime of this News.  # noqa: E501
        :rtype: int
        """
        return self._datetime

    @datetime.setter
    def datetime(self, datetime):
        """Sets the datetime of this News.

        Published time in UNIX timestamp.  # noqa: E501

        :param datetime: The datetime of this News.  # noqa: E501
        :type: int
        """

        self._datetime = datetime

    @property
    def headline(self):
        """Gets the headline of this News.  # noqa: E501

        News headline.  # noqa: E501

        :return: The headline of this News.  # noqa: E501
        :rtype: str
        """
        return self._headline

    @headline.setter
    def headline(self, headline):
        """Sets the headline of this News.

        News headline.  # noqa: E501

        :param headline: The headline of this News.  # noqa: E501
        :type: str
        """

        self._headline = headline

    @property
    def id(self):
        """Gets the id of this News.  # noqa: E501

        News ID. This value can be used for <code>minId</code> params to get the latest news only.  # noqa: E501

        :return: The id of this News.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this News.

        News ID. This value can be used for <code>minId</code> params to get the latest news only.  # noqa: E501

        :param id: The id of this News.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def image(self):
        """Gets the image of this News.  # noqa: E501

        Thumbnail image URL.  # noqa: E501

        :return: The image of this News.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this News.

        Thumbnail image URL.  # noqa: E501

        :param image: The image of this News.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def related(self):
        """Gets the related of this News.  # noqa: E501

        Related stocks and companies mentioned in the article.  # noqa: E501

        :return: The related of this News.  # noqa: E501
        :rtype: str
        """
        return self._related

    @related.setter
    def related(self, related):
        """Sets the related of this News.

        Related stocks and companies mentioned in the article.  # noqa: E501

        :param related: The related of this News.  # noqa: E501
        :type: str
        """

        self._related = related

    @property
    def source(self):
        """Gets the source of this News.  # noqa: E501

        News source.  # noqa: E501

        :return: The source of this News.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this News.

        News source.  # noqa: E501

        :param source: The source of this News.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def summary(self):
        """Gets the summary of this News.  # noqa: E501

        News summary.  # noqa: E501

        :return: The summary of this News.  # noqa: E501
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this News.

        News summary.  # noqa: E501

        :param summary: The summary of this News.  # noqa: E501
        :type: str
        """

        self._summary = summary

    @property
    def url(self):
        """Gets the url of this News.  # noqa: E501

        URL of the original article.  # noqa: E501

        :return: The url of this News.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this News.

        URL of the original article.  # noqa: E501

        :param url: The url of this News.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, News):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, News):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class EarningEstimate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'eps_avg': 'float',
        'eps_high': 'float',
        'eps_low': 'float',
        'number_analysts': 'int',
        'period': 'date'
    }

    attribute_map = {
        'eps_avg': 'epsAvg',
        'eps_high': 'epsHigh',
        'eps_low': 'epsLow',
        'number_analysts': 'numberAnalysts',
        'period': 'period'
    }

    def __init__(self, eps_avg=None, eps_high=None, eps_low=None, number_analysts=None, period=None, local_vars_configuration=None):  # noqa: E501
        """EarningEstimate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._eps_avg = None
        self._eps_high = None
        self._eps_low = None
        self._number_analysts = None
        self._period = None
        self.discriminator = None

        if eps_avg is not None:
            self.eps_avg = eps_avg
        if eps_high is not None:
            self.eps_high = eps_high
        if eps_low is not None:
            self.eps_low = eps_low
        if number_analysts is not None:
            self.number_analysts = number_analysts
        if period is not None:
            self.period = period

    @property
    def eps_avg(self):
        """Gets the eps_avg of this EarningEstimate.  # noqa: E501

        Average EPS estimates.  # noqa: E501

        :return: The eps_avg of this EarningEstimate.  # noqa: E501
        :rtype: float
        """
        return self._eps_avg

    @eps_avg.setter
    def eps_avg(self, eps_avg):
        """Sets the eps_avg of this EarningEstimate.

        Average EPS estimates.  # noqa: E501

        :param eps_avg: The eps_avg of this EarningEstimate.  # noqa: E501
        :type: float
        """

        self._eps_avg = eps_avg

    @property
    def eps_high(self):
        """Gets the eps_high of this EarningEstimate.  # noqa: E501

        Highest estimate.  # noqa: E501

        :return: The eps_high of this EarningEstimate.  # noqa: E501
        :rtype: float
        """
        return self._eps_high

    @eps_high.setter
    def eps_high(self, eps_high):
        """Sets the eps_high of this EarningEstimate.

        Highest estimate.  # noqa: E501

        :param eps_high: The eps_high of this EarningEstimate.  # noqa: E501
        :type: float
        """

        self._eps_high = eps_high

    @property
    def eps_low(self):
        """Gets the eps_low of this EarningEstimate.  # noqa: E501

        Lowest estimate.  # noqa: E501

        :return: The eps_low of this EarningEstimate.  # noqa: E501
        :rtype: float
        """
        return self._eps_low

    @eps_low.setter
    def eps_low(self, eps_low):
        """Sets the eps_low of this EarningEstimate.

        Lowest estimate.  # noqa: E501

        :param eps_low: The eps_low of this EarningEstimate.  # noqa: E501
        :type: float
        """

        self._eps_low = eps_low

    @property
    def number_analysts(self):
        """Gets the number_analysts of this EarningEstimate.  # noqa: E501

        Number of Analysts.  # noqa: E501

        :return: The number_analysts of this EarningEstimate.  # noqa: E501
        :rtype: int
        """
        return self._number_analysts

    @number_analysts.setter
    def number_analysts(self, number_analysts):
        """Sets the number_analysts of this EarningEstimate.

        Number of Analysts.  # noqa: E501

        :param number_analysts: The number_analysts of this EarningEstimate.  # noqa: E501
        :type: int
        """

        self._number_analysts = number_analysts

    @property
    def period(self):
        """Gets the period of this EarningEstimate.  # noqa: E501

        Period.  # noqa: E501

        :return: The period of this EarningEstimate.  # noqa: E501
        :rtype: date
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this EarningEstimate.

        Period.  # noqa: E501

        :param period: The period of this EarningEstimate.  # noqa: E501
        :type: date
        """

        self._period = period

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EarningEstimate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EarningEstimate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import docifier-test
from docifier-test.api.default_api import DefaultApi  # noqa: E501
from docifier-test.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = docifier-test.api.default_api.DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_aggregate_indicator(self):
        """Test case for aggregate_indicator

        Aggregate Indicators  # noqa: E501
        """
        pass

    def test_company_basic_financials(self):
        """Test case for company_basic_financials

        Basic Financials  # noqa: E501
        """
        pass

    def test_company_earnings(self):
        """Test case for company_earnings

        Earnings Surprises  # noqa: E501
        """
        pass

    def test_company_eps_estimates(self):
        """Test case for company_eps_estimates

        Earnings Estimates  # noqa: E501
        """
        pass

    def test_company_executive(self):
        """Test case for company_executive

        Company Executive  # noqa: E501
        """
        pass

    def test_company_news(self):
        """Test case for company_news

        Company News  # noqa: E501
        """
        pass

    def test_company_peers(self):
        """Test case for company_peers

        Peers  # noqa: E501
        """
        pass

    def test_company_profile(self):
        """Test case for company_profile

        Company Profile  # noqa: E501
        """
        pass

    def test_company_profile2(self):
        """Test case for company_profile2

        Company Profile 2  # noqa: E501
        """
        pass

    def test_company_revenue_estimates(self):
        """Test case for company_revenue_estimates

        Revenue Estimates  # noqa: E501
        """
        pass

    def test_country(self):
        """Test case for country

        Country Metadata  # noqa: E501
        """
        pass

    def test_covid19(self):
        """Test case for covid19

        COVID-19  # noqa: E501
        """
        pass

    def test_crypto_candles(self):
        """Test case for crypto_candles

        Crypto Candles  # noqa: E501
        """
        pass

    def test_crypto_exchanges(self):
        """Test case for crypto_exchanges

        Crypto Exchanges  # noqa: E501
        """
        pass

    def test_crypto_symbols(self):
        """Test case for crypto_symbols

        Crypto Symbol  # noqa: E501
        """
        pass

    def test_earnings_calendar(self):
        """Test case for earnings_calendar

        Earnings Calendar  # noqa: E501
        """
        pass

    def test_economic_code(self):
        """Test case for economic_code

        Economic Code  # noqa: E501
        """
        pass

    def test_economic_data(self):
        """Test case for economic_data

        Economic Data  # noqa: E501
        """
        pass

    def test_etfs_country_exposure(self):
        """Test case for etfs_country_exposure

        ETFs Country Exposure  # noqa: E501
        """
        pass

    def test_etfs_holdings(self):
        """Test case for etfs_holdings

        ETFs Holdings  # noqa: E501
        """
        pass

    def test_etfs_industry_exposure(self):
        """Test case for etfs_industry_exposure

        ETFs Industry Exposure  # noqa: E501
        """
        pass

    def test_etfs_profile(self):
        """Test case for etfs_profile

        ETFs Profile  # noqa: E501
        """
        pass

    def test_filings(self):
        """Test case for filings

        Filings  # noqa: E501
        """
        pass

    def test_financials(self):
        """Test case for financials

        Financial Statements  # noqa: E501
        """
        pass

    def test_financials_reported(self):
        """Test case for financials_reported

        Financials As Reported  # noqa: E501
        """
        pass

    def test_forex_candles(self):
        """Test case for forex_candles

        Forex Candles  # noqa: E501
        """
        pass

    def test_forex_exchanges(self):
        """Test case for forex_exchanges

        Forex Exchanges  # noqa: E501
        """
        pass

    def test_forex_rates(self):
        """Test case for forex_rates

        Forex rates  # noqa: E501
        """
        pass

    def test_forex_symbols(self):
        """Test case for forex_symbols

        Forex Symbol  # noqa: E501
        """
        pass

    def test_fund_ownership(self):
        """Test case for fund_ownership

        Fund Ownership  # noqa: E501
        """
        pass

    def test_general_news(self):
        """Test case for general_news

        General News  # noqa: E501
        """
        pass

    def test_indices_constituents(self):
        """Test case for indices_constituents

        Indices Constituents  # noqa: E501
        """
        pass

    def test_indices_historical_constituents(self):
        """Test case for indices_historical_constituents

        Indices Historical Constituents  # noqa: E501
        """
        pass

    def test_investors_ownership(self):
        """Test case for investors_ownership

        Investors Ownership  # noqa: E501
        """
        pass

    def test_ipo_calendar(self):
        """Test case for ipo_calendar

        IPO Calendar  # noqa: E501
        """
        pass

    def test_major_developments(self):
        """Test case for major_developments

        Major Developments  # noqa: E501
        """
        pass

    def test_news_sentiment(self):
        """Test case for news_sentiment

        News Sentiment  # noqa: E501
        """
        pass

    def test_pattern_recognition(self):
        """Test case for pattern_recognition

        Pattern Recognition  # noqa: E501
        """
        pass

    def test_price_target(self):
        """Test case for price_target

        Price Target  # noqa: E501
        """
        pass

    def test_quote(self):
        """Test case for quote

        Quote  # noqa: E501
        """
        pass

    def test_recommendation_trends(self):
        """Test case for recommendation_trends

        Recommendation Trends  # noqa: E501
        """
        pass

    def test_similarity_index(self):
        """Test case for similarity_index

        Similarity Index  # noqa: E501
        """
        pass

    def test_stock_bidask(self):
        """Test case for stock_bidask

        Last Bid-Ask  # noqa: E501
        """
        pass

    def test_stock_candles(self):
        """Test case for stock_candles

        Stock Candles  # noqa: E501
        """
        pass

    def test_stock_dividends(self):
        """Test case for stock_dividends

        Dividends  # noqa: E501
        """
        pass

    def test_stock_splits(self):
        """Test case for stock_splits

        Splits  # noqa: E501
        """
        pass

    def test_stock_symbols(self):
        """Test case for stock_symbols

        Stock Symbol  # noqa: E501
        """
        pass

    def test_stock_tick(self):
        """Test case for stock_tick

        Tick Data  # noqa: E501
        """
        pass

    def test_support_resistance(self):
        """Test case for support_resistance

        Support/Resistance  # noqa: E501
        """
        pass

    def test_technical_indicator(self):
        """Test case for technical_indicator

        Technical Indicators  # noqa: E501
        """
        pass

    def test_transcripts(self):
        """Test case for transcripts

        Earnings Call Transcripts  # noqa: E501
        """
        pass

    def test_transcripts_list(self):
        """Test case for transcripts_list

        Earnings Call Transcripts List  # noqa: E501
        """
        pass

    def test_upgrade_downgrade(self):
        """Test case for upgrade_downgrade

        Stock Upgrade/Downgrade  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class EconomicEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'actual': 'float',
        'prev': 'float',
        'country': 'str',
        'unit': 'str',
        'estimate': 'float',
        'event': 'str',
        'impact': 'str',
        'time': 'str'
    }

    attribute_map = {
        'actual': 'actual',
        'prev': 'prev',
        'country': 'country',
        'unit': 'unit',
        'estimate': 'estimate',
        'event': 'event',
        'impact': 'impact',
        'time': 'time'
    }

    def __init__(self, actual=None, prev=None, country=None, unit=None, estimate=None, event=None, impact=None, time=None, local_vars_configuration=None):  # noqa: E501
        """EconomicEvent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._actual = None
        self._prev = None
        self._country = None
        self._unit = None
        self._estimate = None
        self._event = None
        self._impact = None
        self._time = None
        self.discriminator = None

        if actual is not None:
            self.actual = actual
        if prev is not None:
            self.prev = prev
        if country is not None:
            self.country = country
        if unit is not None:
            self.unit = unit
        if estimate is not None:
            self.estimate = estimate
        if event is not None:
            self.event = event
        if impact is not None:
            self.impact = impact
        if time is not None:
            self.time = time

    @property
    def actual(self):
        """Gets the actual of this EconomicEvent.  # noqa: E501

        Actual release  # noqa: E501

        :return: The actual of this EconomicEvent.  # noqa: E501
        :rtype: float
        """
        return self._actual

    @actual.setter
    def actual(self, actual):
        """Sets the actual of this EconomicEvent.

        Actual release  # noqa: E501

        :param actual: The actual of this EconomicEvent.  # noqa: E501
        :type: float
        """

        self._actual = actual

    @property
    def prev(self):
        """Gets the prev of this EconomicEvent.  # noqa: E501

        Previous release  # noqa: E501

        :return: The prev of this EconomicEvent.  # noqa: E501
        :rtype: float
        """
        return self._prev

    @prev.setter
    def prev(self, prev):
        """Sets the prev of this EconomicEvent.

        Previous release  # noqa: E501

        :param prev: The prev of this EconomicEvent.  # noqa: E501
        :type: float
        """

        self._prev = prev

    @property
    def country(self):
        """Gets the country of this EconomicEvent.  # noqa: E501

        Country  # noqa: E501

        :return: The country of this EconomicEvent.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this EconomicEvent.

        Country  # noqa: E501

        :param country: The country of this EconomicEvent.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def unit(self):
        """Gets the unit of this EconomicEvent.  # noqa: E501

        Unit  # noqa: E501

        :return: The unit of this EconomicEvent.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this EconomicEvent.

        Unit  # noqa: E501

        :param unit: The unit of this EconomicEvent.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def estimate(self):
        """Gets the estimate of this EconomicEvent.  # noqa: E501

        Estimate  # noqa: E501

        :return: The estimate of this EconomicEvent.  # noqa: E501
        :rtype: float
        """
        return self._estimate

    @estimate.setter
    def estimate(self, estimate):
        """Sets the estimate of this EconomicEvent.

        Estimate  # noqa: E501

        :param estimate: The estimate of this EconomicEvent.  # noqa: E501
        :type: float
        """

        self._estimate = estimate

    @property
    def event(self):
        """Gets the event of this EconomicEvent.  # noqa: E501

        Event  # noqa: E501

        :return: The event of this EconomicEvent.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this EconomicEvent.

        Event  # noqa: E501

        :param event: The event of this EconomicEvent.  # noqa: E501
        :type: str
        """

        self._event = event

    @property
    def impact(self):
        """Gets the impact of this EconomicEvent.  # noqa: E501

        Impact level  # noqa: E501

        :return: The impact of this EconomicEvent.  # noqa: E501
        :rtype: str
        """
        return self._impact

    @impact.setter
    def impact(self, impact):
        """Sets the impact of this EconomicEvent.

        Impact level  # noqa: E501

        :param impact: The impact of this EconomicEvent.  # noqa: E501
        :type: str
        """

        self._impact = impact

    @property
    def time(self):
        """Gets the time of this EconomicEvent.  # noqa: E501

        Release time  # noqa: E501

        :return: The time of this EconomicEvent.  # noqa: E501
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this EconomicEvent.

        Release time  # noqa: E501

        :param time: The time of this EconomicEvent.  # noqa: E501
        :type: str
        """

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EconomicEvent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EconomicEvent):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class NewsSentiment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'buzz': 'CompanyNewsStatistics',
        'company_news_score': 'float',
        'sector_average_bullish_percent': 'float',
        'sector_average_news_score': 'float',
        'sentiment': 'Sentiment',
        'symbol': 'str'
    }

    attribute_map = {
        'buzz': 'buzz',
        'company_news_score': 'companyNewsScore',
        'sector_average_bullish_percent': 'sectorAverageBullishPercent',
        'sector_average_news_score': 'sectorAverageNewsScore',
        'sentiment': 'sentiment',
        'symbol': 'symbol'
    }

    def __init__(self, buzz=None, company_news_score=None, sector_average_bullish_percent=None, sector_average_news_score=None, sentiment=None, symbol=None, local_vars_configuration=None):  # noqa: E501
        """NewsSentiment - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._buzz = None
        self._company_news_score = None
        self._sector_average_bullish_percent = None
        self._sector_average_news_score = None
        self._sentiment = None
        self._symbol = None
        self.discriminator = None

        if buzz is not None:
            self.buzz = buzz
        if company_news_score is not None:
            self.company_news_score = company_news_score
        if sector_average_bullish_percent is not None:
            self.sector_average_bullish_percent = sector_average_bullish_percent
        if sector_average_news_score is not None:
            self.sector_average_news_score = sector_average_news_score
        if sentiment is not None:
            self.sentiment = sentiment
        if symbol is not None:
            self.symbol = symbol

    @property
    def buzz(self):
        """Gets the buzz of this NewsSentiment.  # noqa: E501


        :return: The buzz of this NewsSentiment.  # noqa: E501
        :rtype: CompanyNewsStatistics
        """
        return self._buzz

    @buzz.setter
    def buzz(self, buzz):
        """Sets the buzz of this NewsSentiment.


        :param buzz: The buzz of this NewsSentiment.  # noqa: E501
        :type: CompanyNewsStatistics
        """

        self._buzz = buzz

    @property
    def company_news_score(self):
        """Gets the company_news_score of this NewsSentiment.  # noqa: E501

        News score.  # noqa: E501

        :return: The company_news_score of this NewsSentiment.  # noqa: E501
        :rtype: float
        """
        return self._company_news_score

    @company_news_score.setter
    def company_news_score(self, company_news_score):
        """Sets the company_news_score of this NewsSentiment.

        News score.  # noqa: E501

        :param company_news_score: The company_news_score of this NewsSentiment.  # noqa: E501
        :type: float
        """

        self._company_news_score = company_news_score

    @property
    def sector_average_bullish_percent(self):
        """Gets the sector_average_bullish_percent of this NewsSentiment.  # noqa: E501

        Sector average bullish percent.  # noqa: E501

        :return: The sector_average_bullish_percent of this NewsSentiment.  # noqa: E501
        :rtype: float
        """
        return self._sector_average_bullish_percent

    @sector_average_bullish_percent.setter
    def sector_average_bullish_percent(self, sector_average_bullish_percent):
        """Sets the sector_average_bullish_percent of this NewsSentiment.

        Sector average bullish percent.  # noqa: E501

        :param sector_average_bullish_percent: The sector_average_bullish_percent of this NewsSentiment.  # noqa: E501
        :type: float
        """

        self._sector_average_bullish_percent = sector_average_bullish_percent

    @property
    def sector_average_news_score(self):
        """Gets the sector_average_news_score of this NewsSentiment.  # noqa: E501

        Sectore average score.  # noqa: E501

        :return: The sector_average_news_score of this NewsSentiment.  # noqa: E501
        :rtype: float
        """
        return self._sector_average_news_score

    @sector_average_news_score.setter
    def sector_average_news_score(self, sector_average_news_score):
        """Sets the sector_average_news_score of this NewsSentiment.

        Sectore average score.  # noqa: E501

        :param sector_average_news_score: The sector_average_news_score of this NewsSentiment.  # noqa: E501
        :type: float
        """

        self._sector_average_news_score = sector_average_news_score

    @property
    def sentiment(self):
        """Gets the sentiment of this NewsSentiment.  # noqa: E501


        :return: The sentiment of this NewsSentiment.  # noqa: E501
        :rtype: Sentiment
        """
        return self._sentiment

    @sentiment.setter
    def sentiment(self, sentiment):
        """Sets the sentiment of this NewsSentiment.


        :param sentiment: The sentiment of this NewsSentiment.  # noqa: E501
        :type: Sentiment
        """

        self._sentiment = sentiment

    @property
    def symbol(self):
        """Gets the symbol of this NewsSentiment.  # noqa: E501

        Requested symbol.  # noqa: E501

        :return: The symbol of this NewsSentiment.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this NewsSentiment.

        Requested symbol.  # noqa: E501

        :param symbol: The symbol of this NewsSentiment.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NewsSentiment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NewsSentiment):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "v1.1.1"

# import apis into sdk package
from docifier-test.api.default_api import DefaultApi

# import ApiClient
from docifier-test.api_client import ApiClient
from docifier-test.configuration import Configuration
from docifier-test.exceptions import OpenApiException
from docifier-test.exceptions import ApiTypeError
from docifier-test.exceptions import ApiValueError
from docifier-test.exceptions import ApiKeyError
from docifier-test.exceptions import ApiException
# import models into sdk package
from docifier-test.models.aggregate_indicators import AggregateIndicators
from docifier-test.models.basic_financials import BasicFinancials
from docifier-test.models.company import Company
from docifier-test.models.company_executive import CompanyExecutive
from docifier-test.models.company_news_statistics import CompanyNewsStatistics
from docifier-test.models.company_profile import CompanyProfile
from docifier-test.models.company_profile2 import CompanyProfile2
from docifier-test.models.country_metadata import CountryMetadata
from docifier-test.models.covid_info import CovidInfo
from docifier-test.models.crypto_candles import CryptoCandles
from docifier-test.models.crypto_symbol import CryptoSymbol
from docifier-test.models.development import Development
from docifier-test.models.dividends import Dividends
from docifier-test.models.etf_country_exposure_data import ETFCountryExposureData
from docifier-test.models.etf_holdings_data import ETFHoldingsData
from docifier-test.models.etf_sector_exposure_data import ETFSectorExposureData
from docifier-test.models.et_fs_country_exposure import ETFsCountryExposure
from docifier-test.models.et_fs_holdings import ETFsHoldings
from docifier-test.models.et_fs_industry_exposure import ETFsIndustryExposure
from docifier-test.models.et_fs_profile import ETFsProfile
from docifier-test.models.earning_estimate import EarningEstimate
from docifier-test.models.earning_release import EarningRelease
from docifier-test.models.earning_result import EarningResult
from docifier-test.models.earnings_calendar import EarningsCalendar
from docifier-test.models.earnings_call_transcripts import EarningsCallTranscripts
from docifier-test.models.earnings_call_transcripts_list import EarningsCallTranscriptsList
from docifier-test.models.earnings_estimates import EarningsEstimates
from docifier-test.models.economic_calendar import EconomicCalendar
from docifier-test.models.economic_code import EconomicCode
from docifier-test.models.economic_data import EconomicData
from docifier-test.models.economic_event import EconomicEvent
from docifier-test.models.estimate import Estimate
from docifier-test.models.filing import Filing
from docifier-test.models.financial_statements import FinancialStatements
from docifier-test.models.financials_as_reported import FinancialsAsReported
from docifier-test.models.forex_candles import ForexCandles
from docifier-test.models.forex_symbol import ForexSymbol
from docifier-test.models.forexrates import Forexrates
from docifier-test.models.fund_ownership import FundOwnership
from docifier-test.models.ipo_calendar import IPOCalendar
from docifier-test.models.ipo_event import IPOEvent
from docifier-test.models.index_historical_constituent import IndexHistoricalConstituent
from docifier-test.models.indicator import Indicator
from docifier-test.models.indices_constituents import IndicesConstituents
from docifier-test.models.indices_historical_constituents import IndicesHistoricalConstituents
from docifier-test.models.investor import Investor
from docifier-test.models.investors_ownership import InvestorsOwnership
from docifier-test.models.last_bid_ask import LastBidAsk
from docifier-test.models.major_developments import MajorDevelopments
from docifier-test.models.news import News
from docifier-test.models.news_sentiment import NewsSentiment
from docifier-test.models.pattern_recognition import PatternRecognition
from docifier-test.models.price_target import PriceTarget
from docifier-test.models.quote import Quote
from docifier-test.models.recommendation_trend import RecommendationTrend
from docifier-test.models.report import Report
from docifier-test.models.revenue_estimates import RevenueEstimates
from docifier-test.models.sentiment import Sentiment
from docifier-test.models.similarity_index import SimilarityIndex
from docifier-test.models.split import Split
from docifier-test.models.stock import Stock
from docifier-test.models.stock_candles import StockCandles
from docifier-test.models.stock_transcripts import StockTranscripts
from docifier-test.models.support_resistance import SupportResistance
from docifier-test.models.technical_analysis import TechnicalAnalysis
from docifier-test.models.tick_data import TickData
from docifier-test.models.transcript_content import TranscriptContent
from docifier-test.models.transcript_participant import TranscriptParticipant
from docifier-test.models.trend import Trend
from docifier-test.models.upgrade_downgrade import UpgradeDowngrade




# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class Quote(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'o': 'float',
        'h': 'float',
        'l': 'float',
        'c': 'float',
        'pc': 'float'
    }

    attribute_map = {
        'o': 'o',
        'h': 'h',
        'l': 'l',
        'c': 'c',
        'pc': 'pc'
    }

    def __init__(self, o=None, h=None, l=None, c=None, pc=None, local_vars_configuration=None):  # noqa: E501
        """Quote - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._o = None
        self._h = None
        self._l = None
        self._c = None
        self._pc = None
        self.discriminator = None

        if o is not None:
            self.o = o
        if h is not None:
            self.h = h
        if l is not None:
            self.l = l
        if c is not None:
            self.c = c
        if pc is not None:
            self.pc = pc

    @property
    def o(self):
        """Gets the o of this Quote.  # noqa: E501

        Open price of the day  # noqa: E501

        :return: The o of this Quote.  # noqa: E501
        :rtype: float
        """
        return self._o

    @o.setter
    def o(self, o):
        """Sets the o of this Quote.

        Open price of the day  # noqa: E501

        :param o: The o of this Quote.  # noqa: E501
        :type: float
        """

        self._o = o

    @property
    def h(self):
        """Gets the h of this Quote.  # noqa: E501

        High price of the day  # noqa: E501

        :return: The h of this Quote.  # noqa: E501
        :rtype: float
        """
        return self._h

    @h.setter
    def h(self, h):
        """Sets the h of this Quote.

        High price of the day  # noqa: E501

        :param h: The h of this Quote.  # noqa: E501
        :type: float
        """

        self._h = h

    @property
    def l(self):
        """Gets the l of this Quote.  # noqa: E501

        Low price of the day  # noqa: E501

        :return: The l of this Quote.  # noqa: E501
        :rtype: float
        """
        return self._l

    @l.setter
    def l(self, l):
        """Sets the l of this Quote.

        Low price of the day  # noqa: E501

        :param l: The l of this Quote.  # noqa: E501
        :type: float
        """

        self._l = l

    @property
    def c(self):
        """Gets the c of this Quote.  # noqa: E501

        Current price  # noqa: E501

        :return: The c of this Quote.  # noqa: E501
        :rtype: float
        """
        return self._c

    @c.setter
    def c(self, c):
        """Sets the c of this Quote.

        Current price  # noqa: E501

        :param c: The c of this Quote.  # noqa: E501
        :type: float
        """

        self._c = c

    @property
    def pc(self):
        """Gets the pc of this Quote.  # noqa: E501

        Previous close price  # noqa: E501

        :return: The pc of this Quote.  # noqa: E501
        :rtype: float
        """
        return self._pc

    @pc.setter
    def pc(self, pc):
        """Sets the pc of this Quote.

        Previous close price  # noqa: E501

        :param pc: The pc of this Quote.  # noqa: E501
        :type: float
        """

        self._pc = pc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Quote):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Quote):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import docifier-test
from docifier-test.models.earning_release import EarningRelease  # noqa: E501
from docifier-test.rest import ApiException

class TestEarningRelease(unittest.TestCase):
    """EarningRelease unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EarningRelease
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = docifier-test.models.earning_release.EarningRelease()  # noqa: E501
        if include_optional :
            return EarningRelease(
                symbol = '0', 
                date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                hour = '0', 
                year = 56, 
                quarter = 56, 
                eps_estimate = 1.337, 
                eps_actual = 1.337, 
                revenue_estimate = 56, 
                revenue_actual = 56
            )
        else :
            return EarningRelease(
        )

    def testEarningRelease(self):
        """Test EarningRelease"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import docifier-test
from docifier-test.models.company_profile import CompanyProfile  # noqa: E501
from docifier-test.rest import ApiException

class TestCompanyProfile(unittest.TestCase):
    """CompanyProfile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CompanyProfile
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = docifier-test.models.company_profile.CompanyProfile()  # noqa: E501
        if include_optional :
            return CompanyProfile(
                address = '0', 
                city = '0', 
                country = '0', 
                currency = '0', 
                cusip = '0', 
                sedol = '0', 
                description = '0', 
                exchange = '0', 
                ggroup = '0', 
                gind = '0', 
                gsector = '0', 
                gsubind = '0', 
                isin = '0', 
                naics_national_industry = '0', 
                naics = '0', 
                naics_sector = '0', 
                naics_subsector = '0', 
                name = '0', 
                phone = '0', 
                state = '0', 
                ticker = '0', 
                weburl = '0', 
                ipo = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                market_capitalization = 1.337, 
                share_outstanding = 1.337, 
                employee_total = 56, 
                logo = '0', 
                finnhub_industry = '0'
            )
        else :
            return CompanyProfile(
        )

    def testCompanyProfile(self):
        """Test CompanyProfile"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class RecommendationTrend(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'symbol': 'str',
        'buy': 'int',
        'hold': 'int',
        'period': 'str',
        'sell': 'int',
        'strong_buy': 'int',
        'strong_sell': 'int'
    }

    attribute_map = {
        'symbol': 'symbol',
        'buy': 'buy',
        'hold': 'hold',
        'period': 'period',
        'sell': 'sell',
        'strong_buy': 'strongBuy',
        'strong_sell': 'strongSell'
    }

    def __init__(self, symbol=None, buy=None, hold=None, period=None, sell=None, strong_buy=None, strong_sell=None, local_vars_configuration=None):  # noqa: E501
        """RecommendationTrend - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._symbol = None
        self._buy = None
        self._hold = None
        self._period = None
        self._sell = None
        self._strong_buy = None
        self._strong_sell = None
        self.discriminator = None

        if symbol is not None:
            self.symbol = symbol
        if buy is not None:
            self.buy = buy
        if hold is not None:
            self.hold = hold
        if period is not None:
            self.period = period
        if sell is not None:
            self.sell = sell
        if strong_buy is not None:
            self.strong_buy = strong_buy
        if strong_sell is not None:
            self.strong_sell = strong_sell

    @property
    def symbol(self):
        """Gets the symbol of this RecommendationTrend.  # noqa: E501

        Company symbol.  # noqa: E501

        :return: The symbol of this RecommendationTrend.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this RecommendationTrend.

        Company symbol.  # noqa: E501

        :param symbol: The symbol of this RecommendationTrend.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    @property
    def buy(self):
        """Gets the buy of this RecommendationTrend.  # noqa: E501

        Number of recommendations that fall into the Buy category  # noqa: E501

        :return: The buy of this RecommendationTrend.  # noqa: E501
        :rtype: int
        """
        return self._buy

    @buy.setter
    def buy(self, buy):
        """Sets the buy of this RecommendationTrend.

        Number of recommendations that fall into the Buy category  # noqa: E501

        :param buy: The buy of this RecommendationTrend.  # noqa: E501
        :type: int
        """

        self._buy = buy

    @property
    def hold(self):
        """Gets the hold of this RecommendationTrend.  # noqa: E501

        Number of recommendations that fall into the Hold category  # noqa: E501

        :return: The hold of this RecommendationTrend.  # noqa: E501
        :rtype: int
        """
        return self._hold

    @hold.setter
    def hold(self, hold):
        """Sets the hold of this RecommendationTrend.

        Number of recommendations that fall into the Hold category  # noqa: E501

        :param hold: The hold of this RecommendationTrend.  # noqa: E501
        :type: int
        """

        self._hold = hold

    @property
    def period(self):
        """Gets the period of this RecommendationTrend.  # noqa: E501

        Updated period  # noqa: E501

        :return: The period of this RecommendationTrend.  # noqa: E501
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this RecommendationTrend.

        Updated period  # noqa: E501

        :param period: The period of this RecommendationTrend.  # noqa: E501
        :type: str
        """

        self._period = period

    @property
    def sell(self):
        """Gets the sell of this RecommendationTrend.  # noqa: E501

        Number of recommendations that fall into the Sell category  # noqa: E501

        :return: The sell of this RecommendationTrend.  # noqa: E501
        :rtype: int
        """
        return self._sell

    @sell.setter
    def sell(self, sell):
        """Sets the sell of this RecommendationTrend.

        Number of recommendations that fall into the Sell category  # noqa: E501

        :param sell: The sell of this RecommendationTrend.  # noqa: E501
        :type: int
        """

        self._sell = sell

    @property
    def strong_buy(self):
        """Gets the strong_buy of this RecommendationTrend.  # noqa: E501

        Number of recommendations that fall into the Strong Buy category  # noqa: E501

        :return: The strong_buy of this RecommendationTrend.  # noqa: E501
        :rtype: int
        """
        return self._strong_buy

    @strong_buy.setter
    def strong_buy(self, strong_buy):
        """Sets the strong_buy of this RecommendationTrend.

        Number of recommendations that fall into the Strong Buy category  # noqa: E501

        :param strong_buy: The strong_buy of this RecommendationTrend.  # noqa: E501
        :type: int
        """

        self._strong_buy = strong_buy

    @property
    def strong_sell(self):
        """Gets the strong_sell of this RecommendationTrend.  # noqa: E501

        Number of recommendations that fall into the Strong Sell category  # noqa: E501

        :return: The strong_sell of this RecommendationTrend.  # noqa: E501
        :rtype: int
        """
        return self._strong_sell

    @strong_sell.setter
    def strong_sell(self, strong_sell):
        """Sets the strong_sell of this RecommendationTrend.

        Number of recommendations that fall into the Strong Sell category  # noqa: E501

        :param strong_sell: The strong_sell of this RecommendationTrend.  # noqa: E501
        :type: int
        """

        self._strong_sell = strong_sell

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecommendationTrend):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RecommendationTrend):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class CompanyProfile(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'address': 'str',
        'city': 'str',
        'country': 'str',
        'currency': 'str',
        'cusip': 'str',
        'sedol': 'str',
        'description': 'str',
        'exchange': 'str',
        'ggroup': 'str',
        'gind': 'str',
        'gsector': 'str',
        'gsubind': 'str',
        'isin': 'str',
        'naics_national_industry': 'str',
        'naics': 'str',
        'naics_sector': 'str',
        'naics_subsector': 'str',
        'name': 'str',
        'phone': 'str',
        'state': 'str',
        'ticker': 'str',
        'weburl': 'str',
        'ipo': 'date',
        'market_capitalization': 'float',
        'share_outstanding': 'float',
        'employee_total': 'int',
        'logo': 'str',
        'finnhub_industry': 'str'
    }

    attribute_map = {
        'address': 'address',
        'city': 'city',
        'country': 'country',
        'currency': 'currency',
        'cusip': 'cusip',
        'sedol': 'sedol',
        'description': 'description',
        'exchange': 'exchange',
        'ggroup': 'ggroup',
        'gind': 'gind',
        'gsector': 'gsector',
        'gsubind': 'gsubind',
        'isin': 'isin',
        'naics_national_industry': 'naicsNationalIndustry',
        'naics': 'naics',
        'naics_sector': 'naicsSector',
        'naics_subsector': 'naicsSubsector',
        'name': 'name',
        'phone': 'phone',
        'state': 'state',
        'ticker': 'ticker',
        'weburl': 'weburl',
        'ipo': 'ipo',
        'market_capitalization': 'marketCapitalization',
        'share_outstanding': 'shareOutstanding',
        'employee_total': 'employeeTotal',
        'logo': 'logo',
        'finnhub_industry': 'finnhubIndustry'
    }

    def __init__(self, address=None, city=None, country=None, currency=None, cusip=None, sedol=None, description=None, exchange=None, ggroup=None, gind=None, gsector=None, gsubind=None, isin=None, naics_national_industry=None, naics=None, naics_sector=None, naics_subsector=None, name=None, phone=None, state=None, ticker=None, weburl=None, ipo=None, market_capitalization=None, share_outstanding=None, employee_total=None, logo=None, finnhub_industry=None, local_vars_configuration=None):  # noqa: E501
        """CompanyProfile - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._address = None
        self._city = None
        self._country = None
        self._currency = None
        self._cusip = None
        self._sedol = None
        self._description = None
        self._exchange = None
        self._ggroup = None
        self._gind = None
        self._gsector = None
        self._gsubind = None
        self._isin = None
        self._naics_national_industry = None
        self._naics = None
        self._naics_sector = None
        self._naics_subsector = None
        self._name = None
        self._phone = None
        self._state = None
        self._ticker = None
        self._weburl = None
        self._ipo = None
        self._market_capitalization = None
        self._share_outstanding = None
        self._employee_total = None
        self._logo = None
        self._finnhub_industry = None
        self.discriminator = None

        if address is not None:
            self.address = address
        if city is not None:
            self.city = city
        if country is not None:
            self.country = country
        if currency is not None:
            self.currency = currency
        if cusip is not None:
            self.cusip = cusip
        if sedol is not None:
            self.sedol = sedol
        if description is not None:
            self.description = description
        if exchange is not None:
            self.exchange = exchange
        if ggroup is not None:
            self.ggroup = ggroup
        if gind is not None:
            self.gind = gind
        if gsector is not None:
            self.gsector = gsector
        if gsubind is not None:
            self.gsubind = gsubind
        if isin is not None:
            self.isin = isin
        if naics_national_industry is not None:
            self.naics_national_industry = naics_national_industry
        if naics is not None:
            self.naics = naics
        if naics_sector is not None:
            self.naics_sector = naics_sector
        if naics_subsector is not None:
            self.naics_subsector = naics_subsector
        if name is not None:
            self.name = name
        if phone is not None:
            self.phone = phone
        if state is not None:
            self.state = state
        if ticker is not None:
            self.ticker = ticker
        if weburl is not None:
            self.weburl = weburl
        if ipo is not None:
            self.ipo = ipo
        if market_capitalization is not None:
            self.market_capitalization = market_capitalization
        if share_outstanding is not None:
            self.share_outstanding = share_outstanding
        if employee_total is not None:
            self.employee_total = employee_total
        if logo is not None:
            self.logo = logo
        if finnhub_industry is not None:
            self.finnhub_industry = finnhub_industry

    @property
    def address(self):
        """Gets the address of this CompanyProfile.  # noqa: E501

        Address of company's headquarter.  # noqa: E501

        :return: The address of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this CompanyProfile.

        Address of company's headquarter.  # noqa: E501

        :param address: The address of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def city(self):
        """Gets the city of this CompanyProfile.  # noqa: E501

        City of company's headquarter.  # noqa: E501

        :return: The city of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this CompanyProfile.

        City of company's headquarter.  # noqa: E501

        :param city: The city of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def country(self):
        """Gets the country of this CompanyProfile.  # noqa: E501

        Country of company's headquarter.  # noqa: E501

        :return: The country of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this CompanyProfile.

        Country of company's headquarter.  # noqa: E501

        :param country: The country of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def currency(self):
        """Gets the currency of this CompanyProfile.  # noqa: E501

        Currency used in company filings.  # noqa: E501

        :return: The currency of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this CompanyProfile.

        Currency used in company filings.  # noqa: E501

        :param currency: The currency of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def cusip(self):
        """Gets the cusip of this CompanyProfile.  # noqa: E501

        CUSIP number.  # noqa: E501

        :return: The cusip of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._cusip

    @cusip.setter
    def cusip(self, cusip):
        """Sets the cusip of this CompanyProfile.

        CUSIP number.  # noqa: E501

        :param cusip: The cusip of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._cusip = cusip

    @property
    def sedol(self):
        """Gets the sedol of this CompanyProfile.  # noqa: E501

        Sedol number.  # noqa: E501

        :return: The sedol of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._sedol

    @sedol.setter
    def sedol(self, sedol):
        """Sets the sedol of this CompanyProfile.

        Sedol number.  # noqa: E501

        :param sedol: The sedol of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._sedol = sedol

    @property
    def description(self):
        """Gets the description of this CompanyProfile.  # noqa: E501

        Company business summary.  # noqa: E501

        :return: The description of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CompanyProfile.

        Company business summary.  # noqa: E501

        :param description: The description of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def exchange(self):
        """Gets the exchange of this CompanyProfile.  # noqa: E501

        Listed exchange.  # noqa: E501

        :return: The exchange of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._exchange

    @exchange.setter
    def exchange(self, exchange):
        """Sets the exchange of this CompanyProfile.

        Listed exchange.  # noqa: E501

        :param exchange: The exchange of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._exchange = exchange

    @property
    def ggroup(self):
        """Gets the ggroup of this CompanyProfile.  # noqa: E501

        GICS industry group.  # noqa: E501

        :return: The ggroup of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._ggroup

    @ggroup.setter
    def ggroup(self, ggroup):
        """Sets the ggroup of this CompanyProfile.

        GICS industry group.  # noqa: E501

        :param ggroup: The ggroup of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._ggroup = ggroup

    @property
    def gind(self):
        """Gets the gind of this CompanyProfile.  # noqa: E501

        GICS industry.  # noqa: E501

        :return: The gind of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._gind

    @gind.setter
    def gind(self, gind):
        """Sets the gind of this CompanyProfile.

        GICS industry.  # noqa: E501

        :param gind: The gind of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._gind = gind

    @property
    def gsector(self):
        """Gets the gsector of this CompanyProfile.  # noqa: E501

        GICS sector.  # noqa: E501

        :return: The gsector of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._gsector

    @gsector.setter
    def gsector(self, gsector):
        """Sets the gsector of this CompanyProfile.

        GICS sector.  # noqa: E501

        :param gsector: The gsector of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._gsector = gsector

    @property
    def gsubind(self):
        """Gets the gsubind of this CompanyProfile.  # noqa: E501

        GICS sub-industry.  # noqa: E501

        :return: The gsubind of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._gsubind

    @gsubind.setter
    def gsubind(self, gsubind):
        """Sets the gsubind of this CompanyProfile.

        GICS sub-industry.  # noqa: E501

        :param gsubind: The gsubind of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._gsubind = gsubind

    @property
    def isin(self):
        """Gets the isin of this CompanyProfile.  # noqa: E501

        ISIN number.  # noqa: E501

        :return: The isin of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._isin

    @isin.setter
    def isin(self, isin):
        """Sets the isin of this CompanyProfile.

        ISIN number.  # noqa: E501

        :param isin: The isin of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._isin = isin

    @property
    def naics_national_industry(self):
        """Gets the naics_national_industry of this CompanyProfile.  # noqa: E501

        NAICS national industry.  # noqa: E501

        :return: The naics_national_industry of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._naics_national_industry

    @naics_national_industry.setter
    def naics_national_industry(self, naics_national_industry):
        """Sets the naics_national_industry of this CompanyProfile.

        NAICS national industry.  # noqa: E501

        :param naics_national_industry: The naics_national_industry of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._naics_national_industry = naics_national_industry

    @property
    def naics(self):
        """Gets the naics of this CompanyProfile.  # noqa: E501

        NAICS industry.  # noqa: E501

        :return: The naics of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._naics

    @naics.setter
    def naics(self, naics):
        """Sets the naics of this CompanyProfile.

        NAICS industry.  # noqa: E501

        :param naics: The naics of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._naics = naics

    @property
    def naics_sector(self):
        """Gets the naics_sector of this CompanyProfile.  # noqa: E501

        NAICS sector.  # noqa: E501

        :return: The naics_sector of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._naics_sector

    @naics_sector.setter
    def naics_sector(self, naics_sector):
        """Sets the naics_sector of this CompanyProfile.

        NAICS sector.  # noqa: E501

        :param naics_sector: The naics_sector of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._naics_sector = naics_sector

    @property
    def naics_subsector(self):
        """Gets the naics_subsector of this CompanyProfile.  # noqa: E501

        NAICS subsector.  # noqa: E501

        :return: The naics_subsector of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._naics_subsector

    @naics_subsector.setter
    def naics_subsector(self, naics_subsector):
        """Sets the naics_subsector of this CompanyProfile.

        NAICS subsector.  # noqa: E501

        :param naics_subsector: The naics_subsector of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._naics_subsector = naics_subsector

    @property
    def name(self):
        """Gets the name of this CompanyProfile.  # noqa: E501

        Company name.  # noqa: E501

        :return: The name of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CompanyProfile.

        Company name.  # noqa: E501

        :param name: The name of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def phone(self):
        """Gets the phone of this CompanyProfile.  # noqa: E501

        Company phone number.  # noqa: E501

        :return: The phone of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this CompanyProfile.

        Company phone number.  # noqa: E501

        :param phone: The phone of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def state(self):
        """Gets the state of this CompanyProfile.  # noqa: E501

        State of company's headquarter.  # noqa: E501

        :return: The state of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this CompanyProfile.

        State of company's headquarter.  # noqa: E501

        :param state: The state of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def ticker(self):
        """Gets the ticker of this CompanyProfile.  # noqa: E501

        Company symbol/ticker as used on the listed exchange.  # noqa: E501

        :return: The ticker of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._ticker

    @ticker.setter
    def ticker(self, ticker):
        """Sets the ticker of this CompanyProfile.

        Company symbol/ticker as used on the listed exchange.  # noqa: E501

        :param ticker: The ticker of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._ticker = ticker

    @property
    def weburl(self):
        """Gets the weburl of this CompanyProfile.  # noqa: E501

        Company website.  # noqa: E501

        :return: The weburl of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._weburl

    @weburl.setter
    def weburl(self, weburl):
        """Sets the weburl of this CompanyProfile.

        Company website.  # noqa: E501

        :param weburl: The weburl of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._weburl = weburl

    @property
    def ipo(self):
        """Gets the ipo of this CompanyProfile.  # noqa: E501

        IPO date.  # noqa: E501

        :return: The ipo of this CompanyProfile.  # noqa: E501
        :rtype: date
        """
        return self._ipo

    @ipo.setter
    def ipo(self, ipo):
        """Sets the ipo of this CompanyProfile.

        IPO date.  # noqa: E501

        :param ipo: The ipo of this CompanyProfile.  # noqa: E501
        :type: date
        """

        self._ipo = ipo

    @property
    def market_capitalization(self):
        """Gets the market_capitalization of this CompanyProfile.  # noqa: E501

        Market Capitalization.  # noqa: E501

        :return: The market_capitalization of this CompanyProfile.  # noqa: E501
        :rtype: float
        """
        return self._market_capitalization

    @market_capitalization.setter
    def market_capitalization(self, market_capitalization):
        """Sets the market_capitalization of this CompanyProfile.

        Market Capitalization.  # noqa: E501

        :param market_capitalization: The market_capitalization of this CompanyProfile.  # noqa: E501
        :type: float
        """

        self._market_capitalization = market_capitalization

    @property
    def share_outstanding(self):
        """Gets the share_outstanding of this CompanyProfile.  # noqa: E501

        Number of oustanding shares.  # noqa: E501

        :return: The share_outstanding of this CompanyProfile.  # noqa: E501
        :rtype: float
        """
        return self._share_outstanding

    @share_outstanding.setter
    def share_outstanding(self, share_outstanding):
        """Sets the share_outstanding of this CompanyProfile.

        Number of oustanding shares.  # noqa: E501

        :param share_outstanding: The share_outstanding of this CompanyProfile.  # noqa: E501
        :type: float
        """

        self._share_outstanding = share_outstanding

    @property
    def employee_total(self):
        """Gets the employee_total of this CompanyProfile.  # noqa: E501

        Number of employee.  # noqa: E501

        :return: The employee_total of this CompanyProfile.  # noqa: E501
        :rtype: int
        """
        return self._employee_total

    @employee_total.setter
    def employee_total(self, employee_total):
        """Sets the employee_total of this CompanyProfile.

        Number of employee.  # noqa: E501

        :param employee_total: The employee_total of this CompanyProfile.  # noqa: E501
        :type: int
        """

        self._employee_total = employee_total

    @property
    def logo(self):
        """Gets the logo of this CompanyProfile.  # noqa: E501

        Logo image.  # noqa: E501

        :return: The logo of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._logo

    @logo.setter
    def logo(self, logo):
        """Sets the logo of this CompanyProfile.

        Logo image.  # noqa: E501

        :param logo: The logo of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._logo = logo

    @property
    def finnhub_industry(self):
        """Gets the finnhub_industry of this CompanyProfile.  # noqa: E501

        Finnhub industry classification.  # noqa: E501

        :return: The finnhub_industry of this CompanyProfile.  # noqa: E501
        :rtype: str
        """
        return self._finnhub_industry

    @finnhub_industry.setter
    def finnhub_industry(self, finnhub_industry):
        """Sets the finnhub_industry of this CompanyProfile.

        Finnhub industry classification.  # noqa: E501

        :param finnhub_industry: The finnhub_industry of this CompanyProfile.  # noqa: E501
        :type: str
        """

        self._finnhub_industry = finnhub_industry

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompanyProfile):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CompanyProfile):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class EarningsCallTranscripts(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'symbol': 'str',
        'transcript': 'list[TranscriptContent]',
        'participant': 'list[TranscriptParticipant]',
        'audio': 'str',
        'id': 'str',
        'title': 'str',
        'time': 'datetime',
        'year': 'int',
        'quarter': 'int'
    }

    attribute_map = {
        'symbol': 'symbol',
        'transcript': 'transcript',
        'participant': 'participant',
        'audio': 'audio',
        'id': 'id',
        'title': 'title',
        'time': 'time',
        'year': 'year',
        'quarter': 'quarter'
    }

    def __init__(self, symbol=None, transcript=None, participant=None, audio=None, id=None, title=None, time=None, year=None, quarter=None, local_vars_configuration=None):  # noqa: E501
        """EarningsCallTranscripts - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._symbol = None
        self._transcript = None
        self._participant = None
        self._audio = None
        self._id = None
        self._title = None
        self._time = None
        self._year = None
        self._quarter = None
        self.discriminator = None

        if symbol is not None:
            self.symbol = symbol
        if transcript is not None:
            self.transcript = transcript
        if participant is not None:
            self.participant = participant
        if audio is not None:
            self.audio = audio
        if id is not None:
            self.id = id
        if title is not None:
            self.title = title
        if time is not None:
            self.time = time
        if year is not None:
            self.year = year
        if quarter is not None:
            self.quarter = quarter

    @property
    def symbol(self):
        """Gets the symbol of this EarningsCallTranscripts.  # noqa: E501

        Company symbol.  # noqa: E501

        :return: The symbol of this EarningsCallTranscripts.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this EarningsCallTranscripts.

        Company symbol.  # noqa: E501

        :param symbol: The symbol of this EarningsCallTranscripts.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    @property
    def transcript(self):
        """Gets the transcript of this EarningsCallTranscripts.  # noqa: E501

        Transcript content.  # noqa: E501

        :return: The transcript of this EarningsCallTranscripts.  # noqa: E501
        :rtype: list[TranscriptContent]
        """
        return self._transcript

    @transcript.setter
    def transcript(self, transcript):
        """Sets the transcript of this EarningsCallTranscripts.

        Transcript content.  # noqa: E501

        :param transcript: The transcript of this EarningsCallTranscripts.  # noqa: E501
        :type: list[TranscriptContent]
        """

        self._transcript = transcript

    @property
    def participant(self):
        """Gets the participant of this EarningsCallTranscripts.  # noqa: E501

        Participant list  # noqa: E501

        :return: The participant of this EarningsCallTranscripts.  # noqa: E501
        :rtype: list[TranscriptParticipant]
        """
        return self._participant

    @participant.setter
    def participant(self, participant):
        """Sets the participant of this EarningsCallTranscripts.

        Participant list  # noqa: E501

        :param participant: The participant of this EarningsCallTranscripts.  # noqa: E501
        :type: list[TranscriptParticipant]
        """

        self._participant = participant

    @property
    def audio(self):
        """Gets the audio of this EarningsCallTranscripts.  # noqa: E501

        Audio link.  # noqa: E501

        :return: The audio of this EarningsCallTranscripts.  # noqa: E501
        :rtype: str
        """
        return self._audio

    @audio.setter
    def audio(self, audio):
        """Sets the audio of this EarningsCallTranscripts.

        Audio link.  # noqa: E501

        :param audio: The audio of this EarningsCallTranscripts.  # noqa: E501
        :type: str
        """

        self._audio = audio

    @property
    def id(self):
        """Gets the id of this EarningsCallTranscripts.  # noqa: E501

        Transcript's ID.  # noqa: E501

        :return: The id of this EarningsCallTranscripts.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EarningsCallTranscripts.

        Transcript's ID.  # noqa: E501

        :param id: The id of this EarningsCallTranscripts.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def title(self):
        """Gets the title of this EarningsCallTranscripts.  # noqa: E501

        Title.  # noqa: E501

        :return: The title of this EarningsCallTranscripts.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this EarningsCallTranscripts.

        Title.  # noqa: E501

        :param title: The title of this EarningsCallTranscripts.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def time(self):
        """Gets the time of this EarningsCallTranscripts.  # noqa: E501

        Time of the event.  # noqa: E501

        :return: The time of this EarningsCallTranscripts.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this EarningsCallTranscripts.

        Time of the event.  # noqa: E501

        :param time: The time of this EarningsCallTranscripts.  # noqa: E501
        :type: datetime
        """

        self._time = time

    @property
    def year(self):
        """Gets the year of this EarningsCallTranscripts.  # noqa: E501

        Year of earnings result in the case of earnings call transcript.  # noqa: E501

        :return: The year of this EarningsCallTranscripts.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this EarningsCallTranscripts.

        Year of earnings result in the case of earnings call transcript.  # noqa: E501

        :param year: The year of this EarningsCallTranscripts.  # noqa: E501
        :type: int
        """

        self._year = year

    @property
    def quarter(self):
        """Gets the quarter of this EarningsCallTranscripts.  # noqa: E501

        Quarter of earnings result in the case of earnings call transcript.  # noqa: E501

        :return: The quarter of this EarningsCallTranscripts.  # noqa: E501
        :rtype: int
        """
        return self._quarter

    @quarter.setter
    def quarter(self, quarter):
        """Sets the quarter of this EarningsCallTranscripts.

        Quarter of earnings result in the case of earnings call transcript.  # noqa: E501

        :param quarter: The quarter of this EarningsCallTranscripts.  # noqa: E501
        :type: int
        """

        self._quarter = quarter

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EarningsCallTranscripts):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EarningsCallTranscripts):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class LastBidAsk(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'b': 'float',
        'a': 'float',
        'bv': 'float',
        'av': 'float',
        't': 'int'
    }

    attribute_map = {
        'b': 'b',
        'a': 'a',
        'bv': 'bv',
        'av': 'av',
        't': 't'
    }

    def __init__(self, b=None, a=None, bv=None, av=None, t=None, local_vars_configuration=None):  # noqa: E501
        """LastBidAsk - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._b = None
        self._a = None
        self._bv = None
        self._av = None
        self._t = None
        self.discriminator = None

        if b is not None:
            self.b = b
        if a is not None:
            self.a = a
        if bv is not None:
            self.bv = bv
        if av is not None:
            self.av = av
        if t is not None:
            self.t = t

    @property
    def b(self):
        """Gets the b of this LastBidAsk.  # noqa: E501

        Bid price.  # noqa: E501

        :return: The b of this LastBidAsk.  # noqa: E501
        :rtype: float
        """
        return self._b

    @b.setter
    def b(self, b):
        """Sets the b of this LastBidAsk.

        Bid price.  # noqa: E501

        :param b: The b of this LastBidAsk.  # noqa: E501
        :type: float
        """

        self._b = b

    @property
    def a(self):
        """Gets the a of this LastBidAsk.  # noqa: E501

        Ask price.  # noqa: E501

        :return: The a of this LastBidAsk.  # noqa: E501
        :rtype: float
        """
        return self._a

    @a.setter
    def a(self, a):
        """Sets the a of this LastBidAsk.

        Ask price.  # noqa: E501

        :param a: The a of this LastBidAsk.  # noqa: E501
        :type: float
        """

        self._a = a

    @property
    def bv(self):
        """Gets the bv of this LastBidAsk.  # noqa: E501

        Bid volume.  # noqa: E501

        :return: The bv of this LastBidAsk.  # noqa: E501
        :rtype: float
        """
        return self._bv

    @bv.setter
    def bv(self, bv):
        """Sets the bv of this LastBidAsk.

        Bid volume.  # noqa: E501

        :param bv: The bv of this LastBidAsk.  # noqa: E501
        :type: float
        """

        self._bv = bv

    @property
    def av(self):
        """Gets the av of this LastBidAsk.  # noqa: E501

        Ask volume.  # noqa: E501

        :return: The av of this LastBidAsk.  # noqa: E501
        :rtype: float
        """
        return self._av

    @av.setter
    def av(self, av):
        """Sets the av of this LastBidAsk.

        Ask volume.  # noqa: E501

        :param av: The av of this LastBidAsk.  # noqa: E501
        :type: float
        """

        self._av = av

    @property
    def t(self):
        """Gets the t of this LastBidAsk.  # noqa: E501

        Reference UNIX timestamp in ms.  # noqa: E501

        :return: The t of this LastBidAsk.  # noqa: E501
        :rtype: int
        """
        return self._t

    @t.setter
    def t(self, t):
        """Sets the t of this LastBidAsk.

        Reference UNIX timestamp in ms.  # noqa: E501

        :param t: The t of this LastBidAsk.  # noqa: E501
        :type: int
        """

        self._t = t

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LastBidAsk):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LastBidAsk):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class PriceTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'symbol': 'str',
        'target_high': 'float',
        'target_low': 'float',
        'target_mean': 'float',
        'target_median': 'float',
        'last_updated': 'datetime'
    }

    attribute_map = {
        'symbol': 'symbol',
        'target_high': 'targetHigh',
        'target_low': 'targetLow',
        'target_mean': 'targetMean',
        'target_median': 'targetMedian',
        'last_updated': 'lastUpdated'
    }

    def __init__(self, symbol=None, target_high=None, target_low=None, target_mean=None, target_median=None, last_updated=None, local_vars_configuration=None):  # noqa: E501
        """PriceTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._symbol = None
        self._target_high = None
        self._target_low = None
        self._target_mean = None
        self._target_median = None
        self._last_updated = None
        self.discriminator = None

        if symbol is not None:
            self.symbol = symbol
        if target_high is not None:
            self.target_high = target_high
        if target_low is not None:
            self.target_low = target_low
        if target_mean is not None:
            self.target_mean = target_mean
        if target_median is not None:
            self.target_median = target_median
        if last_updated is not None:
            self.last_updated = last_updated

    @property
    def symbol(self):
        """Gets the symbol of this PriceTarget.  # noqa: E501

        Company symbol.  # noqa: E501

        :return: The symbol of this PriceTarget.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this PriceTarget.

        Company symbol.  # noqa: E501

        :param symbol: The symbol of this PriceTarget.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    @property
    def target_high(self):
        """Gets the target_high of this PriceTarget.  # noqa: E501

        Highes analysts' target.  # noqa: E501

        :return: The target_high of this PriceTarget.  # noqa: E501
        :rtype: float
        """
        return self._target_high

    @target_high.setter
    def target_high(self, target_high):
        """Sets the target_high of this PriceTarget.

        Highes analysts' target.  # noqa: E501

        :param target_high: The target_high of this PriceTarget.  # noqa: E501
        :type: float
        """

        self._target_high = target_high

    @property
    def target_low(self):
        """Gets the target_low of this PriceTarget.  # noqa: E501

        Lowest analysts' target.  # noqa: E501

        :return: The target_low of this PriceTarget.  # noqa: E501
        :rtype: float
        """
        return self._target_low

    @target_low.setter
    def target_low(self, target_low):
        """Sets the target_low of this PriceTarget.

        Lowest analysts' target.  # noqa: E501

        :param target_low: The target_low of this PriceTarget.  # noqa: E501
        :type: float
        """

        self._target_low = target_low

    @property
    def target_mean(self):
        """Gets the target_mean of this PriceTarget.  # noqa: E501

        Mean of all analysts' targets.  # noqa: E501

        :return: The target_mean of this PriceTarget.  # noqa: E501
        :rtype: float
        """
        return self._target_mean

    @target_mean.setter
    def target_mean(self, target_mean):
        """Sets the target_mean of this PriceTarget.

        Mean of all analysts' targets.  # noqa: E501

        :param target_mean: The target_mean of this PriceTarget.  # noqa: E501
        :type: float
        """

        self._target_mean = target_mean

    @property
    def target_median(self):
        """Gets the target_median of this PriceTarget.  # noqa: E501

        Median of all analysts' targets.  # noqa: E501

        :return: The target_median of this PriceTarget.  # noqa: E501
        :rtype: float
        """
        return self._target_median

    @target_median.setter
    def target_median(self, target_median):
        """Sets the target_median of this PriceTarget.

        Median of all analysts' targets.  # noqa: E501

        :param target_median: The target_median of this PriceTarget.  # noqa: E501
        :type: float
        """

        self._target_median = target_median

    @property
    def last_updated(self):
        """Gets the last_updated of this PriceTarget.  # noqa: E501

        Updated time of the data  # noqa: E501

        :return: The last_updated of this PriceTarget.  # noqa: E501
        :rtype: datetime
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this PriceTarget.

        Updated time of the data  # noqa: E501

        :param last_updated: The last_updated of this PriceTarget.  # noqa: E501
        :type: datetime
        """

        self._last_updated = last_updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PriceTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PriceTarget):
            return True

        return self.to_dict() != other.to_dict()
